(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     10676,        340]
NotebookOptionsPosition[      9937,        314]
NotebookOutlinePosition[     10273,        329]
CellTagsIndexPosition[     10230,        326]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 "The recursion relation is ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["x", 
     RowBox[{"n", "+", "1"}]], "=", 
    RowBox[{
     RowBox[{"y", "(", 
      RowBox[{
       SubscriptBox["x", "n"], ",", "r"}], ")"}], "=", 
     RowBox[{"r", " ", 
      SubscriptBox["x", "n"], 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        SubscriptBox["x", "n"]}]]}]}]}], TraditionalForm]]],
 ":"
}], "Text",
 CellChangeTimes->{{3.498900458449561*^9, 3.4989005055378428`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"y", "[", 
    RowBox[{"x_", ",", "r_"}], "]"}], ":=", 
   RowBox[{"r", " ", "x", " ", 
    RowBox[{"Exp", "[", 
     RowBox[{"-", "x"}], "]"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.498893754984331*^9, 3.498893781029125*^9}}],

Cell[TextData[{
 "We can find the fixed points by solving ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"y", "(", 
     RowBox[{"x", ",", "n"}], ")"}], "=", 
    RowBox[{"x", "=", 
     RowBox[{"r", " ", "x", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", "x"}]]}]}]}], TraditionalForm]],
  FormatType->"TraditionalForm"]
}], "Text",
 CellChangeTimes->{{3.498900508912982*^9, 3.4989005399080477`*^9}}],

Cell[BoxData[
 RowBox[{"fp", "=", 
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"y", "[", 
      RowBox[{"x", ",", "r"}], "]"}], "\[Equal]", "x"}], ",", "x"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.498899868153928*^9, 3.498899876780864*^9}}],

Cell[BoxData[
 RowBox[{"Reduce", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", 
     RowBox[{"x", ",", "r"}], "]"}], "\[Equal]", "x"}], ",", "x", ",", 
   "Reals"}], "]"}]], "Input",
 CellChangeTimes->{{3.498897729687128*^9, 3.498897755140254*^9}, {
  3.498899860178761*^9, 3.498899861471869*^9}, {3.49890009493052*^9, 
  3.4989000958219147`*^9}}],

Cell["The stability indices of the two fixed points are", "Text",
 CellChangeTimes->{{3.4989005579166927`*^9, 3.4989005713833113`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["\[PartialD]", "x"], 
   RowBox[{"y", "[", 
    RowBox[{"x", ",", "r"}], "]"}]}], "/.", "fp"}]], "Input",
 CellChangeTimes->{{3.4988976858542137`*^9, 3.498897728310008*^9}, {
   3.4988977626043797`*^9, 3.498897768840604*^9}, {3.4988978646773787`*^9, 
   3.4988978783389683`*^9}, {3.498899683393055*^9, 3.498899707159781*^9}, {
   3.498899881312729*^9, 3.498899881457837*^9}, 3.498900573176135*^9}],

Cell[TextData[{
 "When the absolute value of the index is less that one, then that fixed \
point is stable.\nSo the ",
 Cell[BoxData[
  FormBox[
   RowBox[{"x", "=", "0"}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " fixed point is stable for ",
 Cell[BoxData[
  FormBox[
   RowBox[{"0", "<", "r", "<", "1"}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " and the ",
 Cell[BoxData[
  FormBox[
   RowBox[{"x", "=", 
    RowBox[{"log", "(", "r", ")"}]}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " fixed point is stable for ",
 Cell[BoxData[
  FormBox[
   RowBox[{"1", "<", "r", "<", 
    SuperscriptBox["\[ExponentialE]", "2"], "\[TildeEqual]", "7.389"}], 
   TraditionalForm]],
  FormatType->"TraditionalForm"],
 "."
}], "Text",
 CellChangeTimes->{{3.49890060226114*^9, 3.4989006847197113`*^9}, {
  3.498900764327901*^9, 3.498900814648382*^9}}],

Cell[BoxData[{
 RowBox[{"Solve", "[", 
  RowBox[{
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"Log", "[", "r", "]"}]}], ")"}], "2"], "\[Equal]", "1"}], ",", 
   "r"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"%", "//", "N"}]}], "Input",
 CellChangeTimes->{{3.498899962643771*^9, 3.4989000328355618`*^9}, {
  3.498900695671446*^9, 3.4989007236203136`*^9}}],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"r", ",", 
     RowBox[{"1", "-", 
      RowBox[{"Log", "[", "r", "]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"r", ",", "0", ",", "5"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.4988976858542137`*^9, 3.498897728310008*^9}, {
   3.4988977626043797`*^9, 3.498897768840604*^9}, {3.4988978646773787`*^9, 
   3.4988978783389683`*^9}, {3.498899683393055*^9, 3.498899707159781*^9}, {
   3.498899881312729*^9, 3.498899881457837*^9}, {3.498900573176135*^9, 
   3.498900598188098*^9}, 3.498902209040576*^9}],

Cell[TextData[{
 "So both are unstable when ",
 Cell[BoxData[
  FormBox[
   RowBox[{"r", ">", 
    SuperscriptBox["\[ExponentialE]", "2"]}], TraditionalForm]]],
 ".  At this point, the system bifurcates and a period two solution starts. \
These are solutions to ",
 Cell[BoxData[
  FormBox[
   RowBox[{"x", "=", 
    RowBox[{
     RowBox[{"y", "(", 
      RowBox[{
       RowBox[{"y", "(", 
        RowBox[{"x", ",", "r"}], ")"}], ",", "r"}], ")"}], "=", 
     RowBox[{
      SuperscriptBox["r", "2"], " ", "x", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"-", "x"}]]}], " ", "x", " ", 
        RowBox[{"(", 
         RowBox[{"r", "+", 
          SuperscriptBox["\[ExponentialE]", "x"]}], ")"}]}]]}]}]}], 
   TraditionalForm]]],
 ".\nThis is hard to solve analytically - but we can examine the solutions \
with"
}], "Text",
 CellChangeTimes->{{3.49890060226114*^9, 3.4989006847197113`*^9}, {
  3.498900764327901*^9, 3.498900815833252*^9}, {3.4989008688053102`*^9, 
  3.49890092421529*^9}, {3.498901186826092*^9, 3.498901204612835*^9}}],

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"Evaluate", "[", 
      RowBox[{"NestList", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"y", "[", 
          RowBox[{"#", ",", "r"}], "]"}], "&"}], ",", "x", ",", "n"}], "]"}], 
      "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "0", ",", "5"}], "}"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"r", ",", "7.389"}], "}"}], ",", "0", ",", "20"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"n", ",", "2", ",", "\"\<Period-n solutions\>\""}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{"1", ",", "2", ",", "3", ",", "4"}], "}"}]}], "}"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.4989008339014263`*^9, 3.4989008658070602`*^9}, {
   3.498900906909788*^9, 3.498900979861203*^9}, 3.498901011323977*^9, {
   3.498901168818871*^9, 3.498901170332616*^9}, {3.498901404297874*^9, 
   3.498901501512219*^9}, {3.498901570476013*^9, 3.4989016194733753`*^9}, 
   3.498901687233289*^9, {3.498901742441228*^9, 3.498901744100748*^9}}],

Cell[TextData[{
 "Finally we can generate the full bifurcation diagram.\nWe use ",
 Cell[BoxData[
  FormBox["NestList", TraditionalForm]],
  FormatType->"TraditionalForm"],
 " to generate a table of points ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    FormBox[
     SubscriptBox["x", "0"],
     TraditionalForm], ",", " ", 
    SubscriptBox["x", "1"], ",", "\[Ellipsis]", " ", ",", 
    SubscriptBox["x", "n"]}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 ", throw away the first few points and take the union of the remaining, \
stabilised points.\nWe plot them with a ",
 Cell[BoxData[
  FormBox["ListPlot", TraditionalForm]],
  FormatType->"TraditionalForm"],
 " and ",
 Cell[BoxData[
  FormBox["Show", TraditionalForm]],
  FormatType->"TraditionalForm"],
 " it together with the ",
 Cell[BoxData[
  FormBox[
   RowBox[{"x", "=", 
    RowBox[{"log", "(", "r", ")"}]}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " fixed point curve."
}], "Text",
 CellChangeTimes->{{3.498900756577764*^9, 3.498900758610125*^9}, {
  3.4989019767553*^9, 3.498902076844767*^9}, {3.498902111636812*^9, 
  3.498902154562132*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"f", "=", 
   RowBox[{"Compile", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"n", ",", "_Integer"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"x0", ",", "_Real"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"r", ",", "_Real"}], "}"}]}], "}"}], ",", 
     RowBox[{"Union", "[", 
      RowBox[{
       RowBox[{"NestList", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"r", " ", "#", " ", 
           RowBox[{"Exp", "[", 
            RowBox[{"-", "#"}], "]"}]}], "&"}], ",", "x0", ",", "n"}], "]"}], 
       "[", 
       RowBox[{"[", 
        RowBox[{
         RowBox[{"-", "10"}], ";;", 
         RowBox[{"-", "1"}]}], "]"}], "]"}], "]"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{"Show", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"ListPlot", "[", 
     RowBox[{
      RowBox[{"Flatten", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"Thread", "[", 
           RowBox[{"{", 
            RowBox[{"r", ",", 
             RowBox[{"f", "[", 
              RowBox[{"1000", ",", ".01", ",", "r"}], "]"}]}], "}"}], "]"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"r", ",", "0", ",", "40", ",", ".01"}], "}"}]}], "]"}], 
        ",", "1"}], "]"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"PointSize", "[", "Tiny", "]"}]}]}], "]"}], ",", 
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"Log", "[", "r", "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"r", ",", "0", ",", "40"}], "}"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", "Red"}]}], "]"}]}], "}"}], 
  "]"}]}], "Input"]
},
WindowSize->{1278, 748},
WindowMargins->{{0, Automatic}, {0, Automatic}},
FrontEndVersion->"7.0 for Linux x86 (64-bit) (February 25, 2009)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[545, 20, 515, 18, 31, "Text"],
Cell[1063, 40, 277, 8, 32, "Input"],
Cell[1343, 50, 428, 13, 31, "Text"],
Cell[1774, 65, 266, 8, 32, "Input"],
Cell[2043, 75, 352, 9, 32, "Input"],
Cell[2398, 86, 135, 1, 31, "Text"],
Cell[2536, 89, 448, 9, 32, "Input"],
Cell[2987, 100, 879, 28, 53, "Text"],
Cell[3869, 130, 402, 11, 55, "Input"],
Cell[4274, 143, 590, 13, 32, "Input"],
Cell[4867, 158, 1138, 32, 55, "Text"],
Cell[6008, 192, 1126, 30, 32, "Input"],
Cell[7137, 224, 1131, 34, 71, "Text"],
Cell[8271, 260, 1662, 52, 77, "Input"]
}
]
*)

(* End of internal cache information *)
